(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27740,       1054]*)
(*NotebookOutlinePosition[     28605,       1082]*)
(*  CellTagsIndexPosition[     28561,       1078]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
This Stylesheet is copyright 1997 by Bruce Carpenter, Math \
Everywhere,Inc.\
\>", "Text"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  ScriptMinSize->12,
  FontSize->18],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  ScriptMinSize->8],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Global"],
  ShowClosedCellArea->True,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->True,
  ShowCellBracket->False,
  CellMargins->{{6, 19}, {8, Inherited}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  TextAlignment->Center,
  LineSpacing->{2, 1},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell[StyleData["Title", "Presentation"],
  CellFrame->True,
  CellMargins->{{24, Inherited}, {60, Inherited}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontSize->36,
  Background->GrayLevel[1]],

Cell[StyleData["Title", "Printout"],
  CellFrame->True,
  CellMargins->{{14, Inherited}, {60, Inherited}},
  TextAlignment->Center,
  FontSize->24,
  Background->GrayLevel[1]],

Cell[StyleData["Title", "Condensed"],
  CellFrame->True,
  CellMargins->{{4, Inherited}, {2, 2}},
  TextAlignment->Center,
  FontSize->24,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellFrame->False,
  ShowCellBracket->False,
  ShowClosedCellArea->True,
  CellMargins->{{6, Inherited}, {6, Inherited}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  TextAlignment->Center,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->None,
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subtitle", "Presentation"],
  CellFrame->False,
  CellMargins->{{24, Inherited}, {6, Inherited}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Plain"],

Cell[StyleData["Subtitle", "Printout"],
  CellFrame->False,
  CellMargins->{{14, Inherited}, {6, Inherited}},
  TextAlignment->Center,
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Plain"],

Cell[StyleData["Subtitle", "Condensed"],
  CellFrame->False,
  CellMargins->{{4, Inherited}, {2, 2}},
  TextAlignment->Center,
  FontFamily->"Palatino",
  FontSize->12,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellFrame->True,
  ShowClosedCellArea->True,
  CellMargins->{{6, Inherited}, {6, Inherited}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  TextAlignment->Center,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellFrame->True,
  CellMargins->{{24, Inherited}, {6, Inherited}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontSize->24,
  FontSlant->"Plain",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell[StyleData["Subsubtitle", "Printout"],
  CellFrame->True,
  CellMargins->{{14, Inherited}, {6, Inherited}},
  TextAlignment->Center,
  FontFamily->"Palatino",
  FontSize->24,
  FontSlant->"Plain",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellFrame->True,
  CellMargins->{{4, Inherited}, {2, 2}},
  TextAlignment->Center,
  FontFamily->"Palatino",
  FontSize->24,
  FontSlant->"Plain",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[GraySquare]",
  ShowClosedCellArea->True,
  CellMargins->{{22, Inherited}, {Inherited, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  LineSpacing->{1.5, 1},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, 20}},
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontSize->16,
  FontWeight->"Plain"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, 20}},
  FontFamily->"Palatino",
  FontSize->16,
  FontWeight->"Plain"],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontFamily->"Palatino",
  FontSize->16,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  ShowClosedCellArea->True,
  CellMargins->{{19, Inherited}, {Inherited, 18}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  LineSpacing->{1.5, 1},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, 15}},
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Plain"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, 15}},
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Plain"],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[EmptySquare]",
  ShowClosedCellArea->True,
  CellMargins->{{18, Inherited}, {Inherited, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  LineSpacing->{1.5, 1},
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, 12}},
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontWeight->"Plain"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, 12}},
  FontFamily->"Palatino",
  FontWeight->"Plain"],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontFamily->"Palatino",
  FontWeight->"Plain"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  ShowClosedCellArea->True,
  CellMargins->{{15, Inherited}, {Inherited, Inherited}},
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  LineSpacing->{1.5, 1},
  LimitsPositioningTokens->{},
  FontFamily->"Times",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontFamily->"Palatino",
  FontColor->RGBColor[0, 0, 1],
  Background->None],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontFamily->"Palatino",
  FontColor->RGBColor[0, 0, 1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  ShowClosedCellArea->True,
  CellMargins->{{15, Inherited}, {Inherited, Inherited}},
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  LineSpacing->{1.5, 1},
  LimitsPositioningTokens->{},
  FontFamily->"Palatino",
  FontSize->14],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontFamily->"Palatino",
  FontSize->12],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontFamily->"Palatino",
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontFamily->"Palatino",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Special1"],
  CellDingbat->"\[EmptySquare]",
  ShowClosedCellArea->True,
  StyleMenuListing->"Special 1",
  FontFamily->"Times",
  FontSize->14,
  FontColor->GrayLevel[0.333333]],

Cell[StyleData["Special1", "Presentation"],
  FontSize->16],

Cell[StyleData["Special1", "Printout"],
  FontSize->12,
  FontColor->GrayLevel[0]],

Cell[StyleData["Special1", "Condensed"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Special2"],
  ShowClosedCellArea->True,
  CellGroupingRules->{"SectionGrouping", 40},
  TextAlignment->Center,
  StyleMenuListing->"Special 2",
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0.333333]],

Cell[StyleData["Special2", "Presentation"],
  TextAlignment->Center,
  FontSize->12],

Cell[StyleData["Special2", "Printout"],
  TextAlignment->Center,
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Special2", "Condensed"],
  TextAlignment->Center,
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Special3"],
  CellDingbat->"\[GraySquare]",
  TextAlignment->Left,
  StyleMenuListing->"Special 3",
  FontFamily->"Courier",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0.333333],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Special3", "Presentation"],
  CellDingbat->"\[GraySquare]",
  TextAlignment->Left,
  FontSize->10],

Cell[StyleData["Special3", "Printout"],
  CellDingbat->"\[GraySquare]",
  TextAlignment->Left,
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Special3", "Condensed"],
  CellDingbat->"\[GraySquare]",
  TextAlignment->Left,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Special4"],
  TextAlignment->Center,
  StyleMenuListing->"Special 4",
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0.333333]],

Cell[StyleData["Special4", "Presentation"],
  TextAlignment->Center,
  FontSize->12],

Cell[StyleData["Special4", "Printout"],
  TextAlignment->Center,
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Special4", "Condensed"],
  TextAlignment->Center,
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Special5"],
  TextAlignment->Center,
  StyleMenuListing->"Special 5",
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0.333333]],

Cell[StyleData["Special5", "Presentation"],
  TextAlignment->Center,
  FontSize->12],

Cell[StyleData["Special5", "Printout"],
  TextAlignment->Center,
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Special5", "Condensed"],
  TextAlignment->Center,
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{45, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{30, Inherited}, {10, Inherited}},
  FontSize->10],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  FontFamily->"Courier",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{45, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{30, Inherited}, {20, Inherited}},
  FontSize->10],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Info"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Info", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Info", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Info", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{15, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Graphics", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->14],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedEquation", "Presentation"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["NumberedEquation", "Condensed"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}]], None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedFigure", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedFigure", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["NumberedFigure", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}]], None}},
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedTable", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["NumberedTable", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["LeftHeader"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["Footer"],
  TextAlignment->Center,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["LeftFooter"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[1, 0, 0.900008],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell["\<\
The \"RefGuide\" style is for linking automatically to the on-line \
Reference Guide help system.\
\>", "Text"],

Cell[StyleData["RefGuide"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->Primary,
  StyleMenuListing->None,
  DrawHighlighted->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1, -5},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  DefaultInlineFormatType->DefaultInputInlineFormatType,
  TextAlignment->Left,
  ScriptLevel->1,
  LimitsPositioningTokens->{},
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{598, 426},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
ShowClosedCellArea->False,
MacintoshSystemPageSetup->"\<\
00<0001804P000000]X2:?oQon82n@960dL5:0?l0080001804P000000]X2:001
0000I00000400@4100000BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 52, "Subtitle"],
Cell[1771, 53, 100, 3, 30, "Text"],
Cell[1874, 58, 193, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[2092, 67, 42, 0, 50, "Section"],
Cell[2137, 69, 51, 1, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2191, 72, 73, 2, 42, 36, 0, "StyleData", "All", "Presentation"],
Cell[2267, 76, 164, 4, 36, 33, 0, "StyleData", "All", "Condensed"],
Cell[2434, 82, 104, 2, 36, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2575, 89, 35, 0, 30, "Section"],
Cell[2613, 91, 101, 3, 30, "Text"],
Cell[2717, 96, 79, 2, 36, 25, 0, "StyleData", "Global", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2833, 103, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[2896, 107, 477, 14, 69, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[3376, 123, 202, 6, 132, 40, 0, "StyleData", "Title", "Presentation"],
Cell[3581, 131, 175, 5, 121, 36, 0, "StyleData", "Title", "Printout"],
Cell[3759, 138, 166, 5, 61, 37, 0, "StyleData", "Title", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[3962, 148, 608, 19, 51, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4573, 169, 226, 7, 42, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[4802, 178, 199, 6, 42, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[5004, 186, 191, 6, 34, 40, 0, "StyleData", "Subtitle", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[5232, 197, 597, 18, 76, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5832, 217, 287, 9, 67, 46, 0, "StyleData", "Subsubtitle", 
"Presentation"],
Cell[6122, 228, 260, 8, 67, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[6385, 238, 252, 8, 61, 43, 0, "StyleData", "Subsubtitle", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[6674, 251, 575, 17, 52, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[7252, 270, 181, 5, 57, 42, 0, "StyleData", "Section", "Presentation"],
Cell[7436, 277, 154, 4, 57, 38, 0, "StyleData", "Section", "Printout"],
Cell[7593, 283, 145, 4, 37, 39, 0, "StyleData", "Section", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[7775, 292, 564, 17, 51, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[8342, 311, 184, 5, 51, 45, 0, "StyleData", "Subsection", "Presentation"],

Cell[8529, 318, 157, 4, 51, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[8689, 324, 148, 4, 36, 42, 0, "StyleData", "Subsection", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[8874, 333, 523, 16, 51, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[9400, 351, 171, 4, 48, 48, 0, "StyleData", "Subsubsection", 
"Presentation"],
Cell[9574, 357, 144, 3, 48, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[9721, 362, 135, 3, 36, 45, 0, "StyleData", "Subsubsection", "Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9905, 371, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[9969, 375, 328, 9, 67, 23, 0, "StyleData", "Text", "All"],
Cell[10300, 386, 171, 4, 72, 39, 0, "StyleData", "Text", "Presentation"],
Cell[10474, 392, 171, 4, 40, 35, 0, "StyleData", "Text", "Printout"],
Cell[10648, 398, 135, 3, 52, 36, 0, "StyleData", "Text", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[10820, 406, 269, 7, 52, 28, 0, "StyleData", "SmallText", "All"],
Cell[11092, 415, 167, 4, 38, 44, 0, "StyleData", "SmallText", "Presentation"],

Cell[11262, 421, 140, 3, 38, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[11405, 426, 124, 3, 34, 41, 0, "StyleData", "SmallText", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[11566, 434, 194, 6, 51, 27, 0, "StyleData", "Special1", "All",
  StyleMenuListing->"Special 1"],
Cell[11763, 442, 59, 1, 40, 43, 0, "StyleData", "Special1", "Presentation"],
Cell[11825, 445, 82, 2, 36, 39, 0, "StyleData", "Special1", "Printout"],
Cell[11910, 449, 56, 1, 36, 40, 0, "StyleData", "Special1", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[12003, 455, 234, 7, 47, 27, 0, "StyleData", "Special2", "All",
  StyleMenuListing->"Special 2"],
Cell[12240, 464, 84, 2, 36, 43, 0, "StyleData", "Special2", "Presentation"],
Cell[12327, 468, 107, 3, 35, 39, 0, "StyleData", "Special2", "Printout"],
Cell[12437, 473, 80, 2, 32, 40, 0, "StyleData", "Special2", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[12554, 480, 339, 12, 35, 27, 0, "StyleData", "Special3", "All",
  StyleMenuListing->"Special 3"],
Cell[12896, 494, 114, 3, 35, 43, 0, "StyleData", "Special3", "Presentation"],
Cell[13013, 499, 137, 4, 35, 39, 0, "StyleData", "Special3", "Printout"],
Cell[13153, 505, 111, 3, 35, 40, 0, "StyleData", "Special3", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[13301, 513, 160, 5, 35, 27, 0, "StyleData", "Special4", "All",
  StyleMenuListing->"Special 4"],
Cell[13464, 520, 84, 2, 36, 43, 0, "StyleData", "Special4", "Presentation"],
Cell[13551, 524, 107, 3, 35, 39, 0, "StyleData", "Special4", "Printout"],
Cell[13661, 529, 80, 2, 32, 40, 0, "StyleData", "Special4", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[13778, 536, 160, 5, 35, 27, 0, "StyleData", "Special5", "All",
  StyleMenuListing->"Special 5"],
Cell[13941, 543, 84, 2, 36, 43, 0, "StyleData", "Special5", "Presentation"],
Cell[14028, 547, 107, 3, 35, 39, 0, "StyleData", "Special5", "Printout"],
Cell[14138, 552, 80, 2, 32, 40, 0, "StyleData", "Special5", "Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14267, 560, 42, 0, 30, "Section"],
Cell[14312, 562, 248, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[14585, 571, 437, 12, 37, 24, 0, "StyleData", "Input", "All"],
Cell[15025, 585, 114, 2, 53, 40, 0, "StyleData", "Input", "Presentation"],
Cell[15142, 589, 103, 2, 40, 36, 0, "StyleData", "Input", "Printout"],
Cell[15248, 593, 94, 2, 30, 37, 0, "StyleData", "Input", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[15379, 600, 496, 14, 38, 25, 0, "StyleData", "Output", "All"],
Cell[15878, 616, 115, 2, 54, 41, 0, "StyleData", "Output", "Presentation"],
Cell[15996, 620, 104, 2, 51, 37, 0, "StyleData", "Output", "Printout"],
Cell[16103, 624, 95, 2, 31, 38, 0, "StyleData", "Output", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[16235, 631, 446, 12, 36, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[16684, 645, 139, 3, 40, 42, 0, "StyleData", "Message", "Presentation"],
Cell[16826, 650, 139, 3, 35, 38, 0, "StyleData", "Message", "Printout"],
Cell[16968, 655, 96, 2, 31, 39, 0, "StyleData", "Message", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[17101, 662, 445, 12, 36, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[17549, 676, 121, 2, 36, 40, 0, "StyleData", "Print", "Presentation"],
Cell[17673, 680, 110, 2, 35, 36, 0, "StyleData", "Print", "Printout"],
Cell[17786, 684, 94, 2, 31, 37, 0, "StyleData", "Print", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[17917, 691, 444, 12, 36, 23, 0, "StyleData", "Info", "All",
  StyleMenuListing->None],
Cell[18364, 705, 120, 2, 36, 39, 0, "StyleData", "Info", "Presentation"],
Cell[18487, 709, 109, 2, 35, 35, 0, "StyleData", "Info", "Printout"],
Cell[18599, 713, 93, 2, 31, 36, 0, "StyleData", "Info", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[18729, 720, 407, 11, 36, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[19139, 733, 124, 2, 36, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[19266, 737, 113, 2, 35, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[19382, 741, 97, 2, 31, 40, 0, "StyleData", "Graphics", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[19516, 748, 124, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[19643, 754, 60, 1, 39, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[19706, 757, 82, 2, 32, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[19791, 761, 56, 1, 32, 41, 0, "StyleData", "CellLabel", "Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19896, 768, 49, 0, 30, "Section"],
Cell[19948, 770, 225, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[20198, 778, 357, 8, 36, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[20558, 788, 125, 2, 70, 51, 0, "StyleData", "NumberedEquation", 
"Presentation"],
Cell[20686, 792, 114, 2, 70, 47, 0, "StyleData", "NumberedEquation", 
"Printout"],
Cell[20803, 796, 115, 2, 70, 48, 0, "StyleData", "NumberedEquation", 
"Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[20955, 803, 313, 7, 56, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[21271, 812, 123, 2, 70, 49, 0, "StyleData", "NumberedFigure", 
"Presentation"],
Cell[21397, 816, 119, 2, 70, 45, 0, "StyleData", "NumberedFigure", 
"Printout"],
Cell[21519, 820, 103, 2, 70, 46, 0, "StyleData", "NumberedFigure", 
"Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[21659, 827, 309, 7, 56, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[21971, 836, 122, 2, 70, 48, 0, "StyleData", "NumberedTable", 
"Presentation"],
Cell[22096, 840, 118, 2, 70, 44, 0, "StyleData", "NumberedTable", "Printout"],

Cell[22217, 844, 102, 2, 70, 45, 0, "StyleData", "NumberedTable", "Condensed"]

}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22368, 852, 49, 0, 30, "Section"],
Cell[22420, 854, 90, 3, 36, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[22513, 859, 94, 3, 36, 29, 0, "StyleData", "LeftHeader", "All",
  StyleMenuListing->None],
Cell[22610, 864, 115, 4, 36, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[22728, 870, 94, 3, 36, 29, 0, "StyleData", "LeftFooter", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[22859, 878, 33, 0, 30, "Section"],
Cell[22895, 880, 121, 3, 30, "Text"],
Cell[23019, 885, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23248, 892, 295, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23546, 901, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[23949, 912, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24339, 923, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[24777, 937, 35, 0, 30, "Section"],
Cell[24815, 939, 184, 4, 46, "Text"],
Cell[25002, 945, 309, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[25314, 955, 121, 3, 30, "Text"],
Cell[25438, 960, 289, 7, 36, 27, 0, "StyleData", "RefGuide", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[25764, 972, 37, 0, 30, "Section"],
Cell[25804, 974, 115, 3, 30, "Text"],
Cell[25922, 979, 145, 5, 36, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[26070, 986, 182, 6, 36, 39, 0, "StyleData", "SelectionPlaceholder", 
"All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[26289, 997, 36, 0, 30, "Section"],
Cell[26328, 999, 258, 5, 46, "Text"],
Cell[26589, 1006, 263, 8, 36, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[26855, 1016, 106, 3, 36, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[26964, 1021, 150, 5, 37, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[27117, 1028, 108, 3, 36, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[27228, 1033, 179, 5, 36, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[27410, 1040, 115, 3, 30, "Text"],
Cell[27528, 1045, 184, 5, 36, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

