(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53938,       2223]*)
(*NotebookOutlinePosition[     54686,       2249]*)
(*  CellTagsIndexPosition[     54642,       2245]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Teaching With Technology\nIn The Classroom\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 2004 Gulf Conference\nSultan Qaboos University\nMuscat, Oman\nBy \
Elias Saab",
    FontColor->RGBColor[1, 0, 0]]
}], "Title"],

Cell[CellGroupData[{

Cell["\<\
Mathematica  Initializations
\
\>", "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Graphics`Colors`\"]
Off[General::spell];
Off[General::spell1];
Off[ParametricPlot3D::ppcom];
Off[ParametricPlot::ppcom];
Off[Plot::plnr];
SetOptions[Limit,Analytic->True];
SetOptions[Plot,AspectRatio->1/GoldenRatio];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["CMView = {2.7, 1.6, 1.2};", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["ThreeAxes[u,v]", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
ThreeAxes[u_,v_] := 
      Graphics3D[{
            {Blue,Line[{{-u,0,0},{u,0,0}}]},
                    Text[\"x\",{u + v,0,0}],
            {Blue,Line[{{0,-u,0},{0,u,0}}]},
                    Text[\"y\",{0, u + v,0}],
            {Blue,Line[{{0,0,0},{0,0,u}}]},
                    Text[\"z\",{0,0,u + v}]}]; 
ThreeAxes[u_] := ThreeAxes[u,u/8];
ThreeAxes::usage = \"ThreeAxes[a,b] makes a standard cartesian axis graphics \
object
\twith x, y, and z running from -a to a, and with axis
\tlabels b units beyond the tips of the axes.  ThreeAxes[a]
\tis ThreeAxes[a,a/8].\";\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Vector Drawers", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
BeginPackage[\"Vectors3D`\",\"Graphics`Colors`\"];

(* Last repair, February, 1993,  Bill Davis   *)

Perp::usage = \"Perp[expr] returns a single 3-d vector which is 
\t\tperpendicular to the vector, 'expr'.\";
\t\t
Cross::usage = \"Cross[a,b] returns the cross product of a and b.\";

Norm::usage = \"Norm[expr] returns the Euclidean length of the
\t\tvector, 'expr'.\";
\t\t
Turn::usage = \"Turn[expr] returns an orthogonal 3 by 3 matrix 
\t\twhich takes {0,0,1} to 'expr'.\";
\t\t
Vector::notnum = \"The vectors `1` and `2` aren't numeric.\";
\t\t
Arrow::usage = \"Arrow[expr] produces a 2 or 3 dimensional 
\tvector from the origin to expr. Arrow[expr,Tail->tail] gives a 
\tvector from tail to expr.  RGBColor and Thickness may be added as 
\toptions\";
\t
Vector::usage = \"Vector[a,b] gives a vector from a to b. 
\t\t\tRGBColor and Thickness may be added as options\";

Vector2D::usage = \"Vector2D[a,b] produces a 2-d graphics object, a 
  \t\tvector from a to b. Vector[a,b,options] produces the 
  \t\tgraphics object with the styles such as RGBColor and 
  \t\tThickness included.\";
\t\t
Vector3D::usage = \"Vector3D[a,b] produces the 3-d graphics object,
\t\ta vector from a to b.  Vector3D[a,b,options] produces the 
\t\tgraphics object with the options such as RGBColor and 
\t\tThickness included.\";
\t\t
Begin[\"`Private`\"];

SetOptions[ParametricPlot,AspectRatio->Automatic];
SetOptions[Plot,AspectRatio->Automatic];
SetOptions[Graphics,AspectRatio->Automatic];

colorQ[a_]:=(Head[a]===RGBColor);
grayQ[a_]:=(Head[a]===GrayLevel);
thickQ[a_]:=(Head[a]===Thickness);
notruleQ[u_] := !(Head[u]===Rule);
ruleQ[u_] := (Head[u]===Rule);

Perp[a_?VectorQ] := If[a[[1]]==0,Return[{1,0,0}],
\t\t\t If[a[[2]]==0,Return[{0,1,0}],
\t\t\t  Return[{-a[[2]],a[[1]],0}]]];
\t\t\t
Cross[a_?VectorQ,b_?VectorQ]:={a[[2]]b[[3]]-a[[3]]b[[2]], 
\t\t\t\ta[[3]]b[[1]]-a[[1]]b[[3]],
\t\t\t\ta[[1]]b[[2]]-a[[2]]b[[1]]};
\t\t\t\t
Norm[a_?VectorQ]:=Sqrt[a.a];

Turn[a_?VectorQ] := Module[{A = a, B},
\t\tB = Perp[A]/Norm[Perp[A]];
\t\tA = a/Norm[a];
\t\tReturn[Transpose[{B,A~Cross~B,A}]]
\t\t\t\t\t];
\t\t\t\t\t
corn = Table[N[1/4 {1.3Cos[2 k Pi/7],1.3Sin[2 k Pi/7],-4}],
\t{k,0,9}]; 

corners[a_] := N[Table[(a.corn[[j]]),{j,1,10}]]; 

head[A_,a_,b_,hr___] := 
\tModule[{HR},
\tHR=ToExpression[\"HeadRatio\"]/.Select[hr,ruleQ]/.
\t\t(ToExpression[\"HeadRatio\"]->.17);
\tReturn[Flatten[
\t\tTable[{b,b+HR Norm[b-a] corners[A][[j-1]],
\t\t\tb + HR Norm[b-a] corners[A][[j]]},{j,2,9}],1]]];
\t\t\t\t

Vector3D[a_,b_,opts___] := 
\tModule[{A,B,AA,BB,m,aa,bb,bob,boob,booob},
\t\taa=N[a];bb=N[b];
\t\tIf[!NumberQ[aa.aa+bb.bb],
\t\t\tMessage[Vector::notnum,a,b];Return[Null],\t\t\t\t\t
\t\t\tIf[Chop[aa-bb]=={0.,0.,0.},
\t\t\t\tB={bb,bb},
\t\t\t\tA = Turn[bb-aa];
\t\t\t\tB = head[A,aa,bb,{opts}]];
\t\tbob=Join[Select[{opts},colorQ],Select[{opts},thickQ],
\t\t\tSelect[{opts},grayQ]];
\t\tboob=Join[Select[{opts},colorQ],Select[{opts},grayQ]];
\t\tbooob=If[Length[boob]==0,RGBColor[0,0,0],
\t\t\t\tboob[[1]]];\t\t\t
\t\tReturn[Graphics3D[{Join[bob,{Line[{aa,bb}]}],
\t\t\t{SurfaceColor[booob],Polygon[B]}}]]
\t\t\t\t\t]];
\t\t\t\t\t\t\t\t\t
\t\t\t\t\t\t\t\t\t

Vector2D[from_,to_,opts___] := Module[{A,B,AA,BB,c,d,a},
\t\t\tAA=N[to];
\t\t\tBB=N[from];
\t\t\t
\t\t\tIf[!NumberQ[AA.AA+BB.BB],
\t\t\t\tMessage[Vector::notnum,from,to];
\t\t\t\tReturn[Null],
\t\t\tA=AA-BB;
\t\t\t
\t\t\ta = Join[Select[{opts},colorQ],Select[{opts},
\t\t\t\tthickQ],Select[{opts},grayQ]];
\t\t\t
\t\t\tIf[Chop[AA-BB]=={0.,0.},
\t\t\t\tReturn[Graphics[{Join[a,{Line[{BB,AA}]}]}]],
\t\t\t
\t\t\tB = RotateLeft[A] {-1,1};
\t\t\te = ToExpression[\"HeadRatio\"]/.
\t\t\t\t\tSelect[{opts},ruleQ]/.
\t\t\t\t{ToExpression[\"HeadRatio\"]->.21};
\t\t\tc = AA - e A + e/3 B;
\t\t\td = AA - e A - e/3 B;
\t\t\t\t\t\t
\t\t\tReturn[
\t\t\tGraphics[{Join[a,{Line[{BB,AA}]}],
\t\t\t\t\tJoin[a,{Polygon[{AA,c,d}]}]}]]]]];
\t\t\t\t\t\t
\t\t\t\t\t
Vector[from_,to_,opts___]:=
\tIf[Length[N[from]]==2,Return[Vector2D[from,to,opts]],
\t\tReturn[Vector3D[from,to,s]]];
\t\t
Arrow[vec_,opts___]:= 
\tModule[{a,b},
\t\t\t\tIf[Length[N[vec]]==2,
\t\t\t\ta=ToExpression[\"Tail\"]/.Select[{opts},ruleQ]/.
\t\t\t\t\t{ToExpression[\"Tail\"]->{0,0}};
\t\t\t\tReturn[Vector2D[a,a+vec,opts]],
\t\t\t\ta=ToExpression[\"Tail\"]/.Select[{opts},ruleQ]/.
\t\t\t\t\t{ToExpression[\"Tail\"]->{0,0,0}};
\t\t\t\tReturn[Vector3D[a,a+vec,opts]]]
\t\t\t\t];
\t
\t
(*Protect[Perp,Cross,Turn,Vector3D,Vector2D,Vector,Arrow];*)

End[];


EndPackage[];
Null\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Spherical Setup", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[polar]
polar[{x_,y_,z_}]:=
{Sqrt[x^2+y^2+z^2],ArcTan[y/x],ArcCos[z/Sqrt[x^2+y^2+z^2]]};
Clear[X]
length[X_]:=Sqrt[X.X];
rr=3;
R=5;
scale=0.8;
red=RGBColor[1,0,0];
blue=RGBColor[0,0,1];
color1=RGBColor[0.8,0.2,0.8];
color2=RGBColor[0.2,0.8,0.2];
black=RGBColor[0,0,0];
Clear[axes]
axes:=Graphics3D[{
Line[{X,{1.5rr,0,0}}],
Line[{X,{0,1.5rr,0}}],
Line[{X,{0,0,2rr}}]}
];
Clear[xyplane]
xyplane:=Graphics3D[Polygon[
{
{-2rr,-2rr,0},
{-2rr, 2rr,0},
{ 2rr, 2rr,0},
{ 2rr,-2rr,0}
}]];
X={0,0,0};
origin=Graphics3D[{black,Point[X]}];
Z={2,3,5};
Clear[point]
point:=Graphics3D[{red,PointSize[0.03],Point[scale Z]}];
Z0={0,0,length[0.8 Z]};
Clear[zpoint]
zpoint=Graphics3D[{black,Point[Z0]}];
XY=scale Z {1,1,0};
Clear[xypoint]
xypoint:=Graphics3D[{black,Point[XY]}];
X0={length[scale Z {1,1,0}],0,0};
xpoint=Graphics3D[{black,Point[X0]}];
Y0={0,length[scale Z {1,1,0}],0};
ypoint=Graphics3D[{black,Point[Y0]}];
Clear[ray]
ray:=Graphics3D[{blue,Line[{X,scale Z}]}];
Clear[ray1]
ray1:=Graphics3D[{color1,Line[{scale Z,Z}]}];
Clear[xyray]
xyray:=Graphics3D[{red,Line[{X, Z {1,1,0}}]}];
rays:={ray,xyray};
xyaux=
length[0.8 Z](0.8 Z {1,1,0})/length[0.8 Z {1,1,0}];
Clear[zarc]
zarc=Graphics3D[{blue,Line[
Table[Cos[t]{0,0,length[0.8 Z]} + Sin[t]xyaux,
{t,0,polar[0.8 Z][[3]],.1}]
]}];
Clear[zarc1]
zarc1=Graphics3D[{color1,Line[
Table[Cos[t]{0,0,length[0.8 Z]} + Sin[t]xyaux,
{t,polar[0.8 Z][[3]],1,.1}]
]}];
Clear[zarc2]
zarc2=Graphics3D[{color1,Line[
Table[Cos[t]{0,0,length[0.8 Z]} + Sin[t]xyaux,
{t,-.8,0,.1}]
]}];
Clear[xyarc]
xyarc=Graphics3D[{blue,Line[
Table[Cos[t] X0 + Sin[t] Y0,
{t,0,polar[XY][[2]],.1}]
]}];
Clear[xyarc1]
xyarc1=Graphics3D[{color1,Line[
Table[Cos[t] X0 + Sin[t] Y0,
{t,-.5,0,.1}]
]}];
Clear[xyarc2]
xyarc2=Graphics3D[{color1,Line[
Table[Cos[t] X0 + Sin[t] Y0,
{t,polar[XY][[2]],polar[XY][[2]]+0.3,.1}]
]}];
Clear[stick]
stick=Graphics3D[{red,Line[{scale Z,XY}]}];

xaxislabel=Text[\"x\",{0.363,0.26}];
yaxislabel = Text[\"y\",{0.73, 0.30}];
zaxislabel = Text[\"z\",{0.50, 0.67}];

stickplot =
Show[xyplane,axes,ray,point,Boxed->False,
ViewPoint->{2.747, 1.594, 1.168},
Epilog->{xaxislabel,yaxislabel,zaxislabel},
DisplayFunction->Identity];

rho=Text[\"r\",{0.53, 0.45}];
rlabel = Show[xyplane,axes,ray,point,
Boxed->False,ViewPoint->{2.747, 1.594, 1.168},
Epilog->{rho,xaxislabel,yaxislabel,zaxislabel},
DisplayFunction->Identity];

phi=Text[\"s\",{0.55, 0.57}];
slabel =
Show[xyplane,zpoint,axes,ray,point,zarc,zarc1,zarc2,Boxed->False,ViewPoint->{\
2.747, 1.594, 1.168},
Epilog->{phi,xaxislabel,yaxislabel,zaxislabel},DisplayFunction->Identity];

theta=Text[\"t\",{0.5, 0.3}];

tlabel=Show[xyplane,axes,xypoint,xpoint,ray,stick,point,xyarc,xyarc1,xyarc2,\
Boxed->False,ViewPoint->{2.747, 1.594, 1.168},
Epilog->{theta,xaxislabel,yaxislabel,zaxislabel},
DisplayFunction->Identity];

all =
Show[xyplane,axes,ray,stick,point,zpoint,xpoint,xypoint,xyarc,xyarc1,xyarc2,\
zarc,zarc1,zarc2,Boxed->False,ViewPoint->{2.747, 1.594, 1.168},
Epilog->{theta,phi,rho,xaxislabel,yaxislabel,zaxislabel},DisplayFunction->\
Identity];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Crisscross", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x]
crisscross = Plot[{Cos[x],Sin[x]},{x,Pi/8,3 Pi/8},
    PlotStyle->{{RGBColor[1,0,0],Thickness[0.02]}},
    Axes->None,AspectRatio->1/3,
    DisplayFunction->Identity];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local Intializations", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[grad,expr,var];
grad[expr_, var_List] := D[expr, #]& /@ var;
grad[expr_]:=grad[expr,{x,y,z}]\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\

Clear[Curl]
Curl[expr_List,vars_List]:= 
{D[expr[[3]],vars[[2]]] - D[expr[[2]],vars[[3]]],
 - D[expr[[3]],vars[[1]]] + D[expr[[1]],vars[[3]]],
 D[expr[[2]],vars[[1]]] - D[expr[[1]],vars[[2]]]}/;
 Length[expr]==Length[vars]


Curl[expr_List]:=Curl[expr,{x,y,z}];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\

Clear[Div,expr,vars]
Div[expr_List,vars_List]:=Inner[D,expr,vars] /; 
Length[expr]==Length[vars]


Div[expr_List]:=Div[expr,{x,y,z}]\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\
Clear[jacobian,jacobiandet]
jacobian[expr_List,vars_List]:=Outer[D,  expr ,vars]/;
Length[expr]==Length[vars]

jacobiandet[expr_List,vars_List]:=
Simplify[Det[jacobian[expr,vars]]]/;
Length[expr]==Length[vars]
 \
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["Clear[rho,phi,t]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\


Unprotect[SA];
Clear[SA,expr,vars];
SA[expr_List,vars_List]:=
Simplify[Norm[ Cross[ D[expr,vars[[1]] ]  ,
             D[ expr,vars[[2]]] ]]]/;
(Length[expr]==3&&Length[vars]==2);

Protect[SA];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\


Unprotect[NV];
Clear[NV,expr,vars];
NV[expr_List,vars_List]:=
Simplify[ Cross[ D[expr,vars[[1]] ]  ,
             D[ expr,vars[[2]]] ]]/;
(Length[expr]==3&&Length[vars]==2);

Protect[NV];
SetOptions[Plot,AspectRatio->1/GoldenRatio];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\
circle = Graphics[{Red,Thickness[0.01],Circle[{0,0},1]}];

Clear[rectangle,t]
rectangle[t_] = 
  Graphics[{Thickness[0.01],Blue,Line[
           {{Cos[t],Sin[t]},
            {-Cos[t],Sin[t]},
            {-Cos[t],-Sin[t]},
            {Cos[t],-Sin[t]},
            {Cos[t],Sin[t]}}]}];

Clear[point]
point[t_] = Graphics[{PointSize[0.02],
       Point[{Cos[t],Sin[t]}]},
       Text[{\"x\",\"y\"},{Cos[t]+.2,Sin[t]}]];
Clear[areameter]

areameter[t_] = Graphics[{Green,Polygon[
     {{1.5,0},{1.5,4 Sin[t]Cos[t]},
     {2.5,4 Sin[t]Cos[t]},{2.5,0},{1.5,0}}]}];
 
\
\>", "Input",
  CellOpen->False,
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\

Needs[\"Graphics`Master`\"]
Off[General::spell];
Off[General::spell1];
Off[ParametricPlot3D::ppcom];
Off[ParametricPlot::ppcom];
Off[Plot::plnr];
SetOptions[Limit,Analytic->True];
SetOptions[Plot, AspectRatio->1/GoldenRatio];\
\>", "Input",
  CellOpen->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here are some examples of how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the Calssroon"
}], "Text"],

Cell[CellGroupData[{

Cell["Test the Definition of the Derivative", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

Remember the definition of the derivative.\
\>", "Text",
  Evaluatable->False],

Cell["\<\

Clear[h,quotient];
quotient=(Sin[x+h]-Sin[x])/h\
\>", "Input"],

Cell["\<\

Let us take a look to the 
following plot and see if 
we can learn something.\
\>", "Text",
  Evaluatable->False],

Cell[TextData[StyleBox["h=1;\nPlot[{Cos[x],quotient},{x,-Pi,Pi},\nPlotStyle->\
\n{{Blue,Thickness[.01]},\n{Red,Thickness[.008]}}];",
  AspectRatioFixed->True]], "Input"],

Cell[TextData[StyleBox["h=.7;\nPlot[{Cos[x],quotient},{x,-Pi,Pi},\n\
PlotStyle->\n{{Blue,Thickness[.01]},\n{Red,Thickness[.008]}}];",
  AspectRatioFixed->True]], "Input"],

Cell["\<\
Table[
  Plot[{Cos[x],quotient},{x,-Pi,Pi},
  PlotStyle->
  {  {Blue,Thickness[.01]},
  {Red,Thickness[.008]}}],
  {h,.9,.1,-.2}];\
\>", "Input",
  AnimationDisplayTime->0.169],

Cell["\<\


Cohabitation of quotient and Cos[x] for h  small. This suggests that
the limit as h approaches zero of  (Sin[x+h]-Sin[x])/h is Cos[x]. 
Hence this plot suggests that the derivative of Sin[x] is Cos[x].\
\>", "Text",
  Evaluatable->False],

Cell["\<\

D[Sin[x],x]\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "An inscribed rectangle in a circle has a maximum area when it is\na \
square. (from Calculus and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ")"
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Let us examine various inscribed rectangle.
Take x > y first.\
\>", "Text",
  Evaluatable->False],

Cell[TextData[StyleBox["t=.2;\nShow[ \
circle,rectangle[t],point[t],areameter[t],\n      AspectRatio->Automatic,\n   \
   Axes->True,AxesOrigin->{0,0},Ticks->None,\n       \
AxesLabel->{\"x\",\"y\"},PlotRange->{-1.1,2.1}];",
  AspectRatioFixed->True]], "Input"],

Cell[TextData[StyleBox["The area of the bar graph on the right represents the \
of the area of the inscribed rectangle.",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False],

Cell[TextData[StyleBox["Increase x a bit and decrease y a bit.",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False],

Cell[TextData[StyleBox["t=.5;\nShow[ \
circle,rectangle[t],point[t],areameter[t],\n      AspectRatio->Automatic,\n   \
   Axes->True,AxesOrigin->{0,0},Ticks->None,\n       \
AxesLabel->{\"x\",\"y\"},PlotRange->{-1.1,2.1}]",
  AspectRatioFixed->True]], "Input"],

Cell["Make x=y", "Text",
  Evaluatable->False],

Cell[TextData[StyleBox["t=Pi/4;\nShow[ \
circle,rectangle[t],point[t],areameter[t],\n      AspectRatio->Automatic,\n   \
   Axes->True,AxesOrigin->{0,0},Ticks->None,\n       \
AxesLabel->{\"x\",\"y\"},PlotRange->{-1.1,2.1}]",
  AspectRatioFixed->True]], "Input"],

Cell[BoxData[""], "Input"],

Cell["Make x < y.", "Text",
  Evaluatable->False],

Cell["\<\
t=Pi/4+.5;
Show[ circle,rectangle[t],point[t],areameter[t],
      AspectRatio->Automatic,
      Axes->True,AxesOrigin->{0,0},Ticks->None,
       AxesLabel->{\"x\",\"y\"},PlotRange->{-1.1,2.1}]\
\>", "Input"],

Cell["Let us try a Movie", "Text",
  Evaluatable->False],

Cell["\<\
Table[Show[ circle,rectangle[t],point[t],areameter[t],
      AspectRatio->Automatic,
      Axes->True,AxesOrigin->{0,0},Ticks->None,
       AxesLabel->{\"x\",\"y\"},PlotRange->{-1.1,2.1}],{t,0, Pi/2,Pi/16}];\
\>", "Input",
  AnimationDisplayTime->2.32981,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell["\<\
Here is a mathematical proof of the above observation:
First let us look at the graph of the area of the inscribed rectangle.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[f,x,side1,side2,area,R]
R=1;
side1[x_]= 2 x;
side2[x_]= 2 Sqrt[R^2-x^2];
area[x_]= side1[x] side2[x];
Plot[area[x],{x,0,1},AspectRatio->1/GoldenRatio,
PlotStyle->{{Thickness[.02],Goldenrod}},DefaultColor->Red];\
\>", "Input"],

Cell["\<\
It seems that this area has a maximum about x =.7
Let us check it out. We have to find the point x where the derivative is \
equal to zero. \
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[ans]
ans=Solve[area'[x] ==0,x]\
\>", "Input"],

Cell["N[%]", "Input"],

Cell["\<\
Is the rectangle sqaure for this  x= 1/Sqrt[2]?
Let us compute the two sides:\
\>", "Text",
  Evaluatable->False],

Cell["{side1[1/Sqrt[2]],side2[1/Sqrt[2]]}", "Input"],

Cell["\<\
Our Example was for a circle of radius one. Is the above result true if  the \
circle has radius R. The two cells below show  that this is the
case.\
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\
Clear[f,x,side1,area,side2,R]
side1[x_]= 2 x;
side2[x_]= 2 Sqrt[R^2-x^2];
area[x_]= side1[x] side2[x]
Solve[area'[x]==0,x]
\
\>", "Input"],

Cell["Let us compare the two sides for this x found above.", "Text",
  Evaluatable->False],

Cell["{side1[R/Sqrt[2]],side2[R/Sqrt[2]]}/. Sqrt[R^2]->R", "Input"],

Cell["Right on the money", "Text",
  Evaluatable->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  " Data fit (from Calculus and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ")"
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[" Polynomial Fit", "Section",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["I) Here are some data and a plot of the data:", "Text",
  Evaluatable->False],

Cell["\<\
data = {{0.23, 1.11}, {0.37, 1.22}, {0.90, 1.35}, 
  {1.72, 1.58}, {1.84, 1.57}, {2.44, 1.74}, 
  {3.21, 2.02}, {3.31, 1.95}, {3.98, 2.31}, 
  {4.70, 2.64}, {4.79, 2.76}};
dataplot = ListPlot[data,PlotStyle->{Red,PointSize[0.02]}];\
\>", "Input"],

Cell["\<\
One of the central uses of minimization is to try to fit data by curves.  \
Usually this involves the idea of least squares.\
\>", "Text",
  Evaluatable->False],

Cell["", "Title",
  Evaluatable->False],

Cell["\<\
Here is how you get the square error function for the data given above: \
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[r,s,x,prelimf,sqerror,k]
prelimf[x_] = r x + s\
\>", "Input"],

Cell["\<\
sqerror[r_,s_] = 
    Sum[(prelimf[data[[k,1]]] - data[[k,2]])^2,
         {k,1,Length[data]}] \
\>", "Input"],

Cell[BoxData[""], "Input"],

Cell[TextData[{
  StyleBox["If you look at the above expression. It is a compicated mess to \
try\nto handle it by hand. Thanks to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" , we do not have to suffer to simplify the above expression that \
we want to\nminimize.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False],

Cell["\<\
sqerror[r_,s_]=Expand[sqerror[r,s]]
\
\>", "Input"],

Cell["\<\
Now you search for the r and s that make sqerror[r,s] as small as it can be.
Of course, you think about the gradient. In reality, we are trying
to find the point {r,s} the makes the derivative of sqerror[r,s] with
respect to r and with respect to s equal to zero.
Try it:\
\>", "Text",
  Evaluatable->False],

Cell["ans=Solve[grad[sqerror[r,s]==0,{r,s}]]", "Input"],

Cell["This tells you what r and s should be for a great fit:", "SmallText",
  Evaluatable->False],

Cell["bestfit[x_] = prelimf[x]/.ans[[1]]", "Input"],

Cell["\<\
fitplot = Plot[bestfit[x],{x,0,5},
      PlotStyle->{{Goldenrod,Thickness[0.01]}},
      DisplayFunction->Identity];
Show[fitplot,dataplot,
      DisplayFunction->$DisplayFunction];\
\>", "Input"]
}, Open  ]],

Cell["\<\
Having done this example, we can modify it to solve a bunch of similar \
problems. Let us look at the next similar problems.\
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\
II) This is a new data. Find the best possible fit using least square
method by functions of the form r + s x + t x^2\
\>", "Text",
  Evaluatable->False],

Cell["\<\
data={{-1.961185, 12.88599}, {-1.728173, 12.186954}, 
{-1.650502, 10.711211}, {-1.223313, 8.80828}, 
{-1.184478, 7.216031}, {-0.796124, 6.361653}, 
{-0.601948, 5.002416}, {-0.25243, 4.691734}, 
{-0.25243, 4.342216}, {0.25243, 3.915027}, 
{0.91263, 4.536392}, {1.184478, 5.779123}, 
{1.495161, 6.478159}, {1.611667, 8.070408}, 
{1.922349, 9.002456}}\
\>", "Input"],

Cell[TextData[StyleBox["dataplot = ListPlot[data,\n\
PlotStyle->{Red,PointSize[0.02]}];",
  AspectRatioFixed->True]], "Input"],

Cell["\<\
A line fit is not going to do it. That is why we are asked to find 
to fit the data with a parabola.
In the next cell, we group the cells that solved our problem above and we \
make some changes. The changes have to reflect that we needto determine three \
unknown mainly r,s and t.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[r,s,t,x,prelimf,sqerror,k,ans]
prelimf[x_] = r   + s x + t x^2;
sqerror[r_,s_,t_] = 
    Sum[(prelimf[data[[k,1]]] - data[[k,2]])^2,
         {k,1,Length[data]}];
 
ans=Solve[grad[sqerror[r,s,t]==0,{r,s,t}]];

bestfit[x_] = prelimf[x]/.ans[[1]] \
\>", "Input"],

Cell["Let us verify our result with a plot.", "Text",
  Evaluatable->False],

Cell["\<\
fitplot = Plot[bestfit[x],{x,-2,2},
      PlotStyle->{{Brown,Thickness[0.01]}},
      DisplayFunction->Identity];
Show[fitplot,dataplot,
      DisplayFunction->$DisplayFunction];\
\>", "Input"]
}, Open  ]],

Cell["One More example of the kind.", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\
III) This is a new data. Find the best possible fit using least square
method by functions of the form r + s x + t x^2 +w x^3\
\>", "Text",
  Evaluatable->False],

Cell["\<\
data={{-1.305768, -2.74787}, {-1.219437, -2.229879}, 
{-1.284186, -1.906135}, {-1.111522, -1.021234}, 
{-1.046773, -0.071584}, {-0.917275, 0.403241}, 
{-0.874109, 0.511156}, {-0.809361, 1.007564}, 
{-0.593531, 1.374474}, {-0.44245, 1.590303}, 
{-0.183455, 1.244976}, {0.053957, 1.093895}, 
{0.161872, 0.61907}, {0.312953, 0.46799}, 
{0.399285, 0.122663}, {0.701446, -0.136333}, 
{1.068356, 0.036331}, {1.089939, 0.381658}, 
{1.284186, 0.705402}, {1.262603, 1.20181}, 
{1.370517, 1.352891}, {1.370517, 1.719801}, 
{1.456849, 1.827716}, {1.3921, 1.914047}};\
\>", "Input"],

Cell["\<\
dataplot = ListPlot[data,
PlotStyle->{Red,PointSize[0.025]}];\
\>", "Input"],

Cell["\<\
A parabola is not going to do it. That is why we need to try a
cubic instead. Here again, we make the changes to reflect the
fact that we need to determine four unknown r,s,t and w.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[r,s,t,x,w,prelimf,sqerror,k,ans]
prelimf[x_] = r   + s x + t x^2 + w x^3;
sqerror[r_,s_,t_,w_] = 
    Sum[(prelimf[data[[k,1]]] - data[[k,2]])^2,
         {k,1,Length[data]}];
 
ans=Solve[grad[sqerror[r,s,t,w]==0,{r,s,t,w}]];

bestfit[x_] = prelimf[x]/.ans[[1]] \
\>", "Input"],

Cell["Confirm with a Plot", "Text",
  Evaluatable->False],

Cell["\<\
fitplot = Plot[bestfit[x],{x,-2,1.5},
      PlotStyle->{{Blue,Thickness[0.015]}},
      DisplayFunction->Identity];
Show[fitplot,dataplot,
      DisplayFunction->$DisplayFunction];\
\>", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["  Fit by Functions other than Polynomial", "Section",
  Evaluatable->False],

Cell["\<\
Clear[data]
data = 
    {{-3., -0.1119}, {-2.5, -0.3986}, 
     {-2., -1.7359}, {-1.5, -2.6926}, 
     {-1., -1.6163}, {-0.5, -0.1308}, 
     {0., 0.0570}, {0.5, 0.2171}, 
     {1., 1.8582}, {1.5, 2.6742}, 
     {2., 1.8313}, {2.5, 0.7550}, 
     {3., 0.2831}}\
\>", "Input"],

Cell["And a plot:", "Text",
  Evaluatable->False],

Cell["\<\
Clear[dataplot]
dataplot = ListPlot[data,PlotStyle->
{PointSize[0.02],Red}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Try to find a function whose plot runs close to all these points.\
\>", "Text",
  Evaluatable->False],

Cell["Answer:", "Special1",
  Evaluatable->False],

Cell["\<\
Looks like points picked of the plot of an odd function plotted from -` to `.
Fourier (1768-1830) revolutionized mathematics with the idea that
 all odd functions plotted on [-`, `] are made up of combinations of Sin[x], \
Sin[2x], Sin[3x], ...
See whether Fourier was right. 
Reach into the box of functions and pull out 
       Sin[x], Sin[2x], and Sin[3x].
Try to fit these data with a function of the form
       r Sin[x] + s Sin[2x] + t Sin[3x],
where r, s, and t are to selected to give the best possible fit.\
\>", "SmallText",
  Evaluatable->False]
}, Open  ]],

Cell["", "Text",
  Evaluatable->False],

Cell["\<\
This  cell that we used to find the polynomial best fit can be used
to solve this problem too. All we need is to change the
functions x, x^2 and x^3 to Sin[x], Sin[2 x] and Sin[3 x].\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[fitter,sqerror,gradsqerror,s,t,r,x,w,u,v,z,k,vars,ans,bestfit]

vars={r,s,t};
fitter[x_] = r Sin[x] + s Sin[2 x] + t Sin[3 x];

sqerror = 
\tSum[(fitter[data[[k,1]]] - data[[k,2]])^2,
\t\t{k,1, Length[data]}]//Expand;
\t\t
gradsqerror = grad[sqerror,vars];


ans=Solve[gradsqerror == Table[0, {i,1,Length[vars]} ]];


bestfit[x_] = fitter[x]/.ans[[1]]\
\>", "Input"],

Cell["Confirm with a plot", "Text",
  Evaluatable->False],

Cell["\<\
Clear[fitplot]
fitplot = Plot[bestfit[x],{x,-3,3},
\tPlotStyle->{{Thickness[0.01],RGBColor[0,0,1]}},
\tDisplayFunction->Identity];

Show[dataplot,fitplot,PlotRange->All];
\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["  Fitting an exponential data.", "Section",
  Evaluatable->False],

Cell["\<\
Clear[data]
data={ {1.367208, 27.818876}, 
{1.927238, 123.183935}, {2.268126, 305.966965}, 
{2.523792, 433.120377}, {2.682061, 687.4272}, 
{2.815982, 766.898083}, {2.852505, 925.839848}, 
{2.937727, 1021.204906}, {2.925553, 1140.41123}, 
{2.9986, 1172.199583}}\
\>", "Input"],

Cell["\<\
Clear[dataplot]
dataplot = ListPlot[data,PlotStyle->
{PointSize[0.02],Red}];\
\>", "Input"],

Cell["\<\
It seems that we have some kind of an exponential growth. Let us confirm by \
plotting the logarithm of the data above.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
logdata=Table[ {data[[k,1]],Log[data[[k,2]]]},
{k,1,Length[data]}];
Clear[logdataplot]
logdataplot = ListPlot[logdata,PlotStyle->
{PointSize[0.02],Red}];\
\>", "Input"],

Cell["\<\
It seems to be a linear data. 
The first attempt is to find a function fitter[x] = r E^(s x) that best fit \
the above data. \
\>", "Text",
  Evaluatable->False],

Cell["\<\
Clear[fitter,sqerror,gradsqerror,s,t,r,x,w,u,v,z,k,vars,ans,bestfit]

vars={r,s};
fitter[x_] = r E^(s x);

sqerror = 
\tSum[(fitter[data[[k,1]]] - data[[k,2]])^2,
\t\t{k,1, Length[data]}]//Expand;
\t\t
gradsqerror = grad[sqerror,vars];


ans=NSolve[gradsqerror == Table[0, {i,1,Length[vars]} ]];


bestfit[x_] = fitter[x]/.ans[[1]]\
\>", "Input"],

Cell[BoxData[
    \(ans\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox["  gave up. But we won't.\nLet us look at the logdata.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False],

Cell["\<\
Now we use that the follwing formula
Log[ r1 E^(s1 x)] = Log[r1]  + s1 x  and try first to best fit the logdata \
with a line.\
\>", "Text",
  Evaluatable->False],

Cell["Find the best line fit for the logdata", "Text",
  Evaluatable->False],

Cell["\<\
Clear[fitter,sqerror,gradsqerror,s,t,r,x,w,u,v,z,k,vars,ans,bestfit]

vars={r,s};
fitter[x_] = r+ s x;

sqerror = 
\tSum[(fitter[logdata[[k,1]]] - logdata[[k,2]])^2,
\t\t{k,1, Length[logdata]}]//Expand;
\t\t
gradsqerror = grad[sqerror,vars];


ans=Solve[gradsqerror == Table[0, {i,1,Length[vars]} ]];


bestfit[x_] = fitter[x]/.ans[[1]]\
\>", "Input"],

Cell["{r,s}={r,s}/. ans[[1]]", "Input"],

Cell["\<\
Noting that Log[ r1 E^(s1 x)] = Log[r1]  + s1 x = r + s x,
then r1=E^r and s1=s. Do this replacement and you are done.\
\>", "Text",
  Evaluatable->False],

Cell["bestexpfit[x_]= E^r E^( s x)", "Input"],

Cell["Confirm with a plot", "Text",
  Evaluatable->False],

Cell["\<\
Clear[fitplot]
fitexpplot = Plot[bestexpfit[x],{x,0,3},
\tPlotStyle->{{Thickness[0.01],RGBColor[0,0,1]}},
\tDisplayFunction->Identity];

Show[dataplot,fitexpplot,PlotRange->All];
\
\>", "Input"],

Cell["Right on the Money", "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
  Why you do not see problems like the above in a traditional Calculus Book?
Can these problems above be done by hand?
Here an attempt to answer the second question which in terms answers the \
first one.\
\>", "Section",
  Evaluatable->False],

Cell[TextData[{
  StyleBox["It's hardly ever a good idea to do this calculus and algebra by \
hand \nbecause the calculations are just too darn tedious. \nDoing them by \
hand is analogous to\n sawing \nmany 4  by 8  sheets of \nplywood in half \
with a hand saw.\n \nYou can do it in theory, but you're going to make lots \
of \nsmall mistakes and you'll be worn out at the end.\n\n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->14,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Carpenters know when power tools are appropriate, \nand so should \
scientists.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->14,
    FontColor->RGBColor[0.703944, 0.0249027, 0.244175]]
}], "Special2",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A nice property of polynomials of degree 3
\
\>", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

1) Let f[x] be the following polynomial of degree 3.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[f,x]
f[x_]=10 - 7*x - 4*x^2 + x^3\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\

2) Let x0=1/8. Find the equation g[x] of the tangent
line to f[x] on the point x0 by completing the following cell:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

Clear[x0,g]
x0=1/8;
g[x_]= f[x0]+ (x-x0)f'[x0]
\
\>", "Input",
  AspectRatioFixed->True],

Cell["3) Plot f[x] and g[x] on the same graph from x=-3 to x=6.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(gr1 = Plot[{f[x], g[x]}, {x, \(-3\), 6}];\)\)], "Input"],

Cell["\<\

4) The tangent g[x] intersects the curve f[x] on another
point. Find the x-coordinate of this point. Call this
x-coordinate x1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ans = Solve[f[x]\  \[Equal] \ g[x], x]\)], "Input"],

Cell[BoxData[
    \(x1 = \ x\  /. \ ans[\([3]\)]\)], "Input"],

Cell["\<\
5) Find the area between f[x] and g[x] from x=x0 to
x=x1. Call this area area1\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(area1\  = \ Integrate[g[x]\  - f[x], {x, x0, x1}]\)], "Input"],

Cell["\<\

6) Find the equation h[x] of the tangent
line to f[x] on the point x1 by completing the following cell\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

Clear[h]

h[x_]= f[x1]+ f'[x1](x-x1)
\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\

7) The tangent h[x] intersects the curve f[x] on another
point. Find the x-coordinate of this point. Call this
x-coordinate x2. Plot h[x] and f[x] on the same graph from x=x2 to x=x1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ans1 = Solve[h[x]\  \[Equal] \ f[x], x]\)], "Input"],

Cell[BoxData[
    \(x2\  = \ x\  /. \ ans1[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(Plot[{f[x], h[x]}, {x, x2, x1}]\)], "Input"],

Cell["\<\
8) Find the area between f[x] and h[x] from x=x2 to
x=x1. Call this area area2.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(area2 = \ \[Integral]\_x2\%x1\((f[x] - 
              h[x])\) \[DifferentialD]x\)], "Input"],

Cell["\<\
The following cell plots f[x], g[x] and h[x] on the  same graph. We are using \
here the 
FilledPlot command in a slick way. Look how g1[x] is defined.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[g1]
g1[x_]:= f[x] /; x <=x0;
g1[x_]:= g[x] /; x> x0;
FilledPlot[{h[x],f[x],g1[x]},{x,x2,x1},
PlotRange->All];\
\>", "Input",
  AspectRatioFixed->True],

Cell["9) Show that area2/area1 =16", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(area2/area1\)], "Input"],

Cell["\<\
10) Repeat all the steps above for a new polynomial f[x] of degree 3
given below and for a new point x0=1/2.  Show that area2/area1=16.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[f,x0,x,h,g1]
x0=-.5;
f[x_]=18 + 4x + 8*x^2 - 3x^3
g[x_]= f[x0]+ (x-x0)f'[x0];
ans=Solve[f[x] \[Equal] g[x],x];
x1= x /. ans[[3]];
area1 = Integrate[g[x] -f[x],{x,x0,x1}];
h[x_]= f[x1]+ f'[x1](x-x1);
ans1=Solve[h[x] \[Equal] f[x],x];
x2 = x /. ans1[[1]];
area2 = Integrate[f[x] -h[x],{x,x2,x1}];
Clear[g1];
g1[x_]:= f[x] /; x <=x0;
g1[x_]:= g[x] /; x> x0;
FilledPlot[{h[x],f[x],g1[x]},{x,x2,x1},
PlotRange->All];
area2/area1\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
11) Now it is time to generalize the above result for a general polynomial of \
degree three and for any starting point x0. Your job is to show that \
area2/area1 is \"always\" equal to this magic number 16. Here is a general \
polynomial of degree 3 and a cleared starting point x0.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]Clear[f, x0, a, x]\n (*\ 
      x0 = \(-\(a[2]\/\(3\ a[3]\)\)\)\ *) \), "\[IndentingNewLine]", 
    \(\(f[x_] = Sum[a[i]\ x^i, {i, 0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        f[x0] + \((x - x0)\) \(f'\)[x0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(ans = Solve[f[x] \[Equal] g[x], x];\)\), "\n", 
    \(\(x1 = x /. ans[\([3]\)];\)\), "\n", 
    \(area1 = 
      Integrate[
        g[x] - f[x], {x, x0, 
          x1}]\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(h[x_] = 
        f[x1] + \(f'\)[x1] \((x - x1)\);\)\n\), "\[IndentingNewLine]", 
    \(\(ans1 = Solve[h[x] \[Equal] f[x], x];\)\), "\n", 
    \(\(x2 = x /. ans1[\([3]\)];\)\n\), "\n", 
    \(area2 = Integrate[f[x] - h[x], {x, x2, x1}]\n\), "\n", 
    \(Simplify[area2/area1]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(f''\)[x] \[Equal] 0, x]\)], "Input"],

Cell[BoxData[{
    \(\[IndentingNewLine]Clear[f, x0, a, x]\), "\n", 
    \(\ x0 = \(-\(a[2]\/\(3\ a[3]\)\)\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = Sum[a[i]\ x^i, {i, 0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        f[x0] + \((x - x0)\) \(f'\)[x0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(ans = Solve[f[x] \[Equal] g[x], x];\)\), "\n", 
    \(\(x1 = x /. ans[\([3]\)];\)\), "\n", 
    \(area1 = 
      Integrate[
        g[x] - f[x], {x, x0, 
          x1}]\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(h[x_] = 
        f[x1] + \(f'\)[x1] \((x - x1)\);\)\n\), "\[IndentingNewLine]", 
    \(\(ans1 = Solve[h[x] \[Equal] f[x], x];\)\), "\n", 
    \(\(x2 = x /. ans1[\([3]\)];\)\n\), "\n", 
    \(area2 = Integrate[f[x] - h[x], {x, x2, x1}]\n\), "\n", 
    \(Simplify[area2/area1]\)}], "Input"]
}, Open  ]],

Cell["\<\

The coefficient a[3] is supposed to be different from zero.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Osculating Circles", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The osculating circle at a  curve y=f[x] at certain point { x0,f[x0]} is a \
circle that has an order of contact 2  with the curve at the point {x0,f[x0]}
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
a) Find the equation of the osculating circle at the curve  f[x]=x^4 at the \
point  {.5,f[.5]}. 
The following cell define f[x], x0 and the equation of the circle. Your job \
is to write down three equations  to help you find a,b and r2.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[eqncircle,x,y,
x0,f,a,b,r2]

f[x_]= x^4 

x0=.5

eqncircle[x_]= (x-a)^2 + (y[x]-b)^2 == r2 \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
a.1) Your job is to write down three equations  to help you find a,b and r2. \
Here is the first
 two equations. Write down the third one.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eqn1 = eqncircle[x] /. {x \[Rule] x0, y[x] \[Rule] f[x0]}\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Clear[eqn1,eqn2,eqn3,x,y,sol]



(* The circle goes through the point {x0,f[x0} *)
eqn1 = 
eqncircle[x] /. {x->x0,y[x]->f[x0]} 


(* The circle and the curve have 
   the same first derivative at x=x0 *)
eqn2= 
eqncircle'[x] /.{x->x0,y[x]->f[x0],y'[x]->f'[x0]}

(* The circle and the curve have 
   the same second derivative at x=x0 *)
eqn3= eqncircle''[x] /.{x->x0,y[x]->f[x0],y'[x]->f'[x0],y''[x]->f''[x0]}


\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(y[x]\)], "Input"]
}, Open  ]],

Cell["\<\
a.2)  Solve the three equations eqn1, eqn2,eqn3 for a,b and r2. Complete the \
following cell:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[sol,radius,a,b,r2 ]
sol=Solve[{ eqn1  , eqn2  , eqn3    }, {a,b,r2}]
{a,b,r2} ={a,b,r2} /. sol[[1]]
radius= Sqrt[r2]\
\>", "Input",
  AspectRatioFixed->True],

Cell["        Notice that r2 is the square of the radius. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
a.3)  Plot the function f[x], the circle and the point {x0,f[x0]} on the same \
graph. Complete the following cell to achieve that goal.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[curve,circleplot,pointplot]

curve=Plot[ f[x], {x,-1,1},
PlotStyle->Red,PlotRange->All,
DisplayFunction->Identity];

pointplot=ListPlot[{ {x0,f[x0]} },
PlotStyle->{PointSize[.04],Blue},
PlotRange->All,
DisplayFunction->Identity];

circleplot=
Graphics[{Thickness[.01],Green,Circle[{a,b},radius]}];

Show[curve,pointplot,circleplot,
AspectRatio->Automatic,
DisplayFunction->$DisplayFunction]

\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "b) Repeat the steps above to find the osculating circle at ",
  StyleBox[" f[x]=Sin[x] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "at the point",
  StyleBox[" { N[Pi/4],f[N[Pi/4]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "}. Be careful to choose a good domain when you plot f[x]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[eqncircle,x,y,
x0,f,a,b,r2]

f[x_]= Cos[x];

x0=N[3Pi/4];

eqncircle[x_]= (x-a)^2 + (y[x]-b)^2 == r2 ;
eqn1=eqncircle[x]/.{x\[Rule]x0,y[x]\[Rule]f[x0]};
Clear[eqn1,eqn2,eqn3,x,y,sol]



(* The circle goes through the point {x0,f[x0} *)
eqn1 = 
eqncircle[x] /. {x->x0,y[x]->f[x0]}; 


(* The circle and the curve have 
   the same first derivative at x=x0 *)
eqn2= 
eqncircle'[x] /.{x->x0,y[x]->f[x0],y'[x]->f'[x0]};

(* The circle and the curve have 
   the same second derivative at x=x0 *)
eqn3= eqncircle''[x] /.{x->x0,y[x]->f[x0],y'[x]->f'[x0],y''[x]->f''[x0]};


Clear[sol,radius,a,b,r2 ]
sol=Solve[{ eqn1  , eqn2  , eqn3    }, {a,b,r2}];
{a,b,r2} ={a,b,r2} /. sol[[1]];
radius= Sqrt[r2];
Clear[curve,circleplot,pointplot]

curve=Plot[ f[x], {x,0,3Pi/2},
PlotStyle->{Red,Thickness[.008]},PlotRange->All,
DisplayFunction->Identity];

pointplot=ListPlot[{ {x0,f[x0]} },
PlotStyle->{PointSize[.04],Blue},
PlotRange->All,
DisplayFunction->Identity];

circleplot=
Graphics[{Thickness[.01],Green,Circle[{a,b},radius]}];

Show[curve,pointplot,circleplot,
AspectRatio->Automatic,
DisplayFunction->$DisplayFunction]

\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Flowing downhill to a minimum", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[f,x,y,cp]
f[x_,y_] = (x^4 + 2 y^4 + 10 x^2 y) / (1 + x^6 + y^6);
Plot3D[f[x,y],{x,-2,2},{y,-2,2},PlotPoints->30];
cp = ContourPlot[f[x,y],{x,-2,2},{y,-2,2}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
There are two minimizers lurking in those two dark regions in the contour \
plot.
Suppose you were to start out near the top of a peak, at\
\>", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["{x0,y0} = {1.0, 0.8};", "Input",
  AspectRatioFixed->True],

Cell["\<\
and try to find the minimizer by simply heading downhill. The downhill \
direction is the oppositte of the gradient direction, so you should begin by \
measuring the gradient:\
\>", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["gradf[x_,y_] = {D[f[x,y],x],D[f[x,y],y]};", "Input",
  AspectRatioFixed->True],

Cell["\<\
You should start out at (x0\[NonBreakingSpace],y0\[NonBreakingSpace]), walk a \
short distance in the direction of -gradf[x0\[NonBreakingSpace],y0\
\[NonBreakingSpace]], measure the gradient at your new position, and repeat \
the performance as many times as necessary. Here's the result:\
\>", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\.0cLet see what happens when we move from {x0,y0} to the point {x1,y1} in \
the direction of -gradf[x0,y0].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,x0,y0,x1,y1,line]

h =.08;
{x0,y0} = {1.0, 0.8};

{x1,y1}  = {x0,y0} - h gradf[x0,y0];

line[1]=Graphics[
{Red,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];
Show[cp,line[1]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["Let us move 2 times.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,x0,y0,x1,y1,line]

h =.08;
{x0,y0} = {1.0, 0.8};

{x1,y1}  = {x0,y0} - h gradf[x0,y0];

line[1]=Graphics[
{Red,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}= {x1,y1};
{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[2]=Graphics[
{Blue,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

Show[cp,line[1],line[2]];\
\>", "Input",
  AspectRatioFixed->True],

Cell["Let us do three steps.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,x0,y0,x1,y1,line]

h =.08;
{x0,y0} = {1.0, 0.8};

{x1,y1}  = {x0,y0} - h gradf[x0,y0];
line[1]=Graphics[
{Red,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}= {x1,y1};
{x1,y1}  = {x0,y0} - h gradf[x0,y0];
line[2]=Graphics[
{Blue,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}= {x1,y1};
{x1,y1}  = {x0,y0} - h gradf[x0,y0];
line[3]=Graphics[
{Magenta,Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

Show[cp,line[1],line[2],line[3]];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Let us do 40 steps. Of course, we are not going to type each steps 40 times. \
We use the Table command.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,p,n,next,path,line,n,i]
n=40;

h = .08;

{xx0,yy0}={1.0, 0.8};

{x0,y0} = {xx0,yy0};
Table[

{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[i]=Graphics[
{RGBColor[Random[],Random[],Random[]],
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}={x1,y1};,

   {i,1,n}];

lines=Table[line[i],{i,1,n}];


Show[cp,lines];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Notice that this prcedure did not end well near the minimum. Let us try a \
small step size.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,p,n,next,path,line,n,i]
n=40;

h = .01;

{xx0,yy0}={1.0, 0.8};

{x0,y0} = {xx0,yy0};
Table[

{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[i]=Graphics[
{RGBColor[Random[],Random[],Random[]],
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}={x1,y1};,

   {i,1,n}];

lines=Table[line[i],{i,1,n}];


Show[cp,lines];\
\>", "Input",
  AspectRatioFixed->True],

Cell["We are not still there. Let us take more than 40 steps.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,p,n,next,path,line,n,i]
n=200;

h = .01;

{xx0,yy0}={1.0, 0.8};

{x0,y0} = {xx0,yy0};
Table[

{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[i]=Graphics[
{RGBColor[Random[],Random[],Random[]],
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}={x1,y1};,

   {i,1,n}];

lines=Table[line[i],{i,1,n}];


Show[cp,lines];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
That is not bad. Let us see the value of f at the last point found.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["{f[x1,y1], {x1,y1}}", "Input",
  AspectRatioFixed->True],

Cell["Let us compare this to the result found by FindMinimum", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["FindMinimum[f[x,y],{x,xx0},{y,yy0}]", "Input",
  AspectRatioFixed->True],

Cell["\<\
That is not bad at all. Can we achieve this point with lesser steps?
In many instances, we can do that by taking first bigger steps and 
then making them smaller in the process.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Clear[x,y,h,j,p,n,next,path,line,n,i]\n\n\nf[x_,y_] = (x^4 + 2 y^4 + 10 \
x^2 y) / (1 + x^6 + y^6);\ncp = ContourPlot[f[x,y],{x,-2,2},{y,-2,2},\n\
DisplayFunction->Identity];\ngradf[x_,y_]= grad[f[x,y],{x,y}];\nn=100;\n\nh = \
.1;\n\n{xx0,yy0}={1.0, 0.8};\n\n{x0,y0} = {xx0,yy0};\nTable[\n\n{x1,y1}  = \
{x0,y0} - h gradf[x0,y0];\n\n\nline[i]=Graphics[\n\
{RGBColor[Random[],Random[],Random[]],\n\
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];\n\n{x0,y0}={x1,y1};\nIf[  \
Mod[i,5]==0,h=h/1.2],\n\n   {i,1,n}];\n\nlines=Table[line[i],{i,1,n}];\n\n\n\
Show[cp,lines,DisplayFunction->$DisplayFunction];\n\nPrint[\"The first result \
found by this cell is given by the first cell\" ]\n\n{f[x1,y1],{x1,y1}}\n\n\
Print[\"the result found by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " built-in Findminimum is the other:\" ]\n\n\n\
FindMinimum[f[x,y],{x,xx0},{y,yy0}]"
}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This method will stop if we encouter a point where the gadient of f is zero. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,p,n,next,path,line,n,i]


f[x_,y_] = (Sin[x^2]+ Sin[y^2])/ (1 + x^2 + y^2);
cp = ContourPlot[f[x,y],{x,-1.5,1.5},{y,-1.5,1.5},
DisplayFunction->Identity];
gradf[x_,y_]= grad[f[x,y],{x,y}];
n=100;

h = .1;

{xx0,yy0}={0, 0};

{x0,y0} = {xx0,yy0};
Table[

{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[i]=Graphics[
{RGBColor[Random[],Random[],Random[]],
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}={x1,y1};
If[  Mod[i,5]==0,h=h/1.2],

   {i,1,n}];

lines=Table[line[i],{i,1,n}];


Show[cp,lines,DisplayFunction->$DisplayFunction];

Print[\"The first result found by this cell is given by the first cell\" ]

{f[x1,y1],{x1,y1}}

Print[\"the result found by Mathematica built-in Findminimum is the other:\" \
]


FindMinimum[f[x,y],{x,xx0},{y,yy0}]\
\>", "Input",
  AspectRatioFixed->True],

Cell["In this case, try another starting point.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[x,y,h,j,p,n,next,path,line,n,i]


f[x_,y_] = (Sin[x^2]+ Sin[y^2])/ (1 + x^2 + y^2);
cp = ContourPlot[f[x,y],{x,-1.5,1.5},{y,-1.5,1.5},
DisplayFunction->Identity];
gradf[x_,y_]= grad[f[x,y],{x,y}];
n=100;

h = .1;

{xx0,yy0}={0.2, .1};

{x0,y0} = {xx0,yy0};
Table[

{x1,y1}  = {x0,y0} - h gradf[x0,y0];


line[i]=Graphics[
{RGBColor[Random[],Random[],Random[]],
Thickness[.01],Line[{{x0,y0},{x1,y1}}]}];

{x0,y0}={x1,y1};
If[  Mod[i,5]==0,h=h/1.2],

   {i,1,n}];

lines=Table[line[i],{i,1,n}];


Show[cp,lines,DisplayFunction->$DisplayFunction];

Print[\"The first result found by this cell is given by the first cell\" ]

{f[x1,y1],{x1,y1}}

Print[\"the result found by Mathematica built-in Findminimum is the other:\" \
]


FindMinimum[f[x,y],{x,xx0},{y,yy0}]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Both results are pointing to the point {0,0} for a possible local minimum.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The Normal and Binormal Vector, Tangential and Normal
Components of the Acceleration\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["The unit Binormal Vector", "Subsubsection"],

Cell["\<\
Clear[P,t,T,x,y,z,ans,NN,B];
P[t_]={x[t],y[t],z[t]};
T[t_]= P'[t]/Norm[P'[t]];
NN[t_]=T'[t]/Norm[T'[t]];
B[t_]= Cross[T[t],NN[t]];
\
\>", "Input"],

Cell["\<\

Let us show that P''[t] is always perpendicular to B[t]\
\>", "Text"],

Cell[BoxData[
    \(ans = \(P''\)[t] . B[t]\)], "Input"],

Cell["Simplify[ans]", "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Nice Plots using the Normal and Binormal Vectors", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Example 1 (Drawing Tubes)", "Subsubsection"],

Cell["Here's a base curve:", "Text"],

Cell["\<\
Clear[t,P]
P[t_] = {Cos[t],Sin[t],t};
curve = ParametricPlot3D[Evaluate[P[t]],{t,0,5},
\t\tAxesLabel->{\"x\",\"y\",\"z\"},ViewPoint->CMView];\
\>", "Input"],

Cell["Draw a Tube of radius 1/2 around it.", "Text"],

Cell[CellGroupData[{

Cell["\<\

Clear[s,T,NN,B,Q]

T[t_] = P'[t]/Norm[P'[t]];
NN[t_]= T'[t]/Norm[T'[t]]//Simplify
B[t_]= Cross[T[t],NN[t]]//Simplify
Q[t_,s_] = P[t] + 1/2 Cos[s] NN[t] + 1/2 Sin[s] B[t]
\
\>", "Input"],

Cell[" ParametricPlot3D[Evaluate[Q[t,s]],{t,0,5},{s,0,2 Pi}];", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2 (Drawing Horns)", "Subsubsection"],

Cell["Here's a base curve:", "Text"],

Cell["\<\
Clear[t,P]
P[t_] = {Cos[t],Sin[t],t};
curve = ParametricPlot3D[Evaluate[P[t]],{t,0,5},
\t\tAxesLabel->{\"x\",\"y\",\"z\"},ViewPoint->CMView];\
\>", "Input"],

Cell["\<\
Draw a horn around it so that the radius of its base at any time t is equal \
1/4 t.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\

Clear[s,T,NN,B,Q]

T[t_] = P'[t]/Norm[P'[t]];
NN[t_]= T'[t]/Norm[T'[t]]//Simplify
B[t_]= Cross[T[t],NN[t]]//Simplify
Q[t_,s_] = P[t] + 1/4 t Cos[s] NN[t] + 1/4 t Sin[s] B[t]
\
\>", "Input"],

Cell[" ParametricPlot3D[Evaluate[Q[t,s]],{t,0,5},{s,0,2 Pi}];", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3 (Drawing Doughnuts)", "Subsubsection"],

Cell["Here's a base curve:", "Text"],

Cell["\<\
Clear[t,P]
P[t_] = {4 Cos[t],4 Sin[t],0};
curve = ParametricPlot3D[Evaluate[P[t]],{t,0,2Pi},
\t\tAxesLabel->{\"x\",\"y\",\"z\"},ViewPoint->CMView];\
\>", "Input"],

Cell["Use it to draw a doughnut whose radius across is equal  1/2.", "Text"],

Cell[CellGroupData[{

Cell["\<\

Clear[s,T,NN,B,Q]

T[t_] = P'[t]/Norm[P'[t]];
NN[t_]= T'[t]/Norm[T'[t]]//Simplify
B[t_]= Cross[T[t],NN[t]]//Simplify
Q[t_,s_] = P[t] + 1/2 Cos[s] NN[t] + 1/2 Sin[s] B[t]
\
\>", "Input"],

Cell[" ParametricPlot3D[Evaluate[Q[t,s]],{t,0,2 Pi},{s,0,2 Pi}];", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3 (Drawing Squashed Doughnuts)", "Subsubsection"],

Cell["Here's a base curve:", "Text"],

Cell["\<\
Clear[t,P]
P[t_] = {4 Cos[t],4 Sin[t],0};
curve = ParametricPlot3D[Evaluate[P[t]],{t,0,2Pi},
\t\tAxesLabel->{\"x\",\"y\",\"z\"},ViewPoint->CMView];\
\>", "Input"],

Cell["\<\
Use it to draw a squashed doughnut whose radius across at any time t  is \
equal  Cos[t] + 1.5\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\

Clear[s,T,NN,B,Q]

T[t_] = P'[t]/Norm[P'[t]];
NN[t_]= T'[t]/Norm[T'[t]]//Simplify
B[t_]= Cross[T[t],NN[t]]//Simplify
Q[t_,s_] = P[t] +(Cos[t] + 1.5) Cos[s] NN[t] + (Cos[t] + 1.5) Sin[s] B[t]
\
\>", "Input"],

Cell[" ParametricPlot3D[Evaluate[Q[t,s]],{t,0,2 Pi},{s,0,2 Pi}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 951}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1222, 709},
WindowMargins->{{Automatic, 3}, {Automatic, 1}},
Magnification->2,
StyleDefinitions -> "C&MStyles.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 335, 9, 735, "Title"],

Cell[CellGroupData[{
Cell[2114, 64, 105, 5, 72, "Special2",
  Evaluatable->False],
Cell[2222, 71, 303, 11, 260, "Input",
  InitializationCell->True],
Cell[2528, 84, 96, 2, 54, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2649, 90, 87, 2, 81, "Subsubsection",
  Evaluatable->False],
Cell[2739, 94, 653, 17, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3429, 116, 87, 2, 50, "Subsubsection",
  Evaluatable->False],
Cell[3519, 120, 4558, 150, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8114, 275, 88, 2, 50, "Subsubsection",
  Evaluatable->False],
Cell[8205, 279, 3121, 121, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11363, 405, 83, 2, 50, "Subsubsection",
  Evaluatable->False],
Cell[11449, 409, 255, 8, 93, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11753, 423, 88, 2, 55, "Subtitle",
  Evaluatable->False],
Cell[11844, 427, 177, 6, 93, "Input",
  InitializationCell->True],
Cell[12024, 435, 341, 13, 93, "Input",
  InitializationCell->True],
Cell[12368, 450, 212, 10, 93, "Input",
  InitializationCell->True],
Cell[12583, 462, 290, 11, 93, "Input",
  InitializationCell->True],
Cell[12876, 475, 87, 2, 93, "Input",
  InitializationCell->True],
Cell[12966, 479, 274, 13, 93, "Input",
  InitializationCell->True],
Cell[13243, 494, 313, 14, 93, "Input",
  InitializationCell->True],
Cell[13559, 510, 662, 26, 93, "Input",
  CellOpen->False,
  InitializationCell->True]
}, Closed]],
Cell[14236, 539, 324, 13, 38, "Input",
  CellOpen->False,
  InitializationCell->True],
Cell[14563, 554, 144, 5, 101, "Text"],

Cell[CellGroupData[{
Cell[14732, 563, 107, 2, 97, "Subsection",
  Evaluatable->False],
Cell[14842, 567, 89, 4, 154, "Text",
  Evaluatable->False],
Cell[14934, 573, 73, 4, 103, "Input"],
Cell[15010, 579, 124, 6, 260, "Text",
  Evaluatable->False],
Cell[15137, 587, 169, 2, 161, "Input"],
Cell[15309, 591, 170, 2, 161, "Input"],
Cell[15482, 595, 186, 8, 190, "Input"],
Cell[15671, 605, 249, 7, 313, "Text",
  Evaluatable->False],
Cell[15923, 614, 37, 3, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15997, 622, 242, 8, 158, "Subsection",
  Evaluatable->False],
Cell[16242, 632, 107, 4, 154, "Text",
  Evaluatable->False],
Cell[16352, 638, 261, 4, 161, "Input"],
Cell[16616, 644, 201, 4, 101, "Text",
  Evaluatable->False],
Cell[16820, 650, 144, 3, 101, "Text",
  Evaluatable->False],
Cell[16967, 655, 260, 4, 161, "Input"],
Cell[17230, 661, 46, 1, 101, "Text",
  Evaluatable->False],
Cell[17279, 664, 262, 4, 161, "Input"],
Cell[17544, 670, 26, 0, 47, "Input"],
Cell[17573, 672, 49, 1, 101, "Text",
  Evaluatable->False],
Cell[17625, 675, 217, 6, 161, "Input"],
Cell[17845, 683, 56, 1, 101, "Text",
  Evaluatable->False],
Cell[17904, 686, 331, 8, 132, "Input"],
Cell[18238, 696, 171, 4, 154, "Text",
  Evaluatable->False],
Cell[18412, 702, 241, 8, 219, "Input"],
Cell[18656, 712, 186, 5, 154, "Text",
  Evaluatable->False],
Cell[18845, 719, 61, 3, 74, "Input"],
Cell[18909, 724, 21, 0, 45, "Input"],
Cell[18933, 726, 123, 4, 154, "Text",
  Evaluatable->False],
Cell[19059, 732, 52, 0, 45, "Input"],
Cell[19114, 734, 194, 5, 207, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19333, 743, 148, 7, 190, "Input"],
Cell[19484, 752, 90, 1, 101, "Text",
  Evaluatable->False],
Cell[19577, 755, 67, 0, 45, "Input"],
Cell[19647, 757, 56, 1, 101, "Text",
  Evaluatable->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19752, 764, 174, 7, 73, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19951, 775, 56, 1, 112, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20032, 780, 83, 1, 101, "Text",
  Evaluatable->False],
Cell[20118, 783, 256, 6, 161, "Input"],
Cell[20377, 791, 170, 4, 154, "Text",
  Evaluatable->False],
Cell[20550, 797, 39, 1, 170, "Title",
  Evaluatable->False],
Cell[20592, 800, 118, 3, 101, "Text",
  Evaluatable->False],
Cell[20713, 805, 77, 3, 74, "Input"],
Cell[20793, 810, 120, 4, 103, "Input"],
Cell[20916, 816, 26, 0, 47, "Input"],
Cell[20945, 818, 480, 14, 260, "Text",
  Evaluatable->False],
Cell[21428, 834, 61, 3, 74, "Input"],
Cell[21492, 839, 317, 7, 313, "Text",
  Evaluatable->False],
Cell[21812, 848, 55, 0, 45, "Input"],
Cell[21870, 850, 97, 1, 69, "SmallText",
  Evaluatable->False],
Cell[21970, 853, 51, 0, 45, "Input"],
Cell[22024, 855, 206, 6, 161, "Input"]
}, Open  ]],
Cell[22245, 864, 170, 4, 154, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22440, 872, 163, 4, 154, "Text",
  Evaluatable->False],
Cell[22606, 878, 373, 9, 248, "Input"],
Cell[22982, 889, 126, 2, 85, "Input"],
Cell[23111, 893, 328, 7, 166, "Text",
  Evaluatable->False],
Cell[23442, 902, 276, 10, 300, "Input"],
Cell[23721, 914, 75, 1, 62, "Text",
  Evaluatable->False],
Cell[23799, 917, 203, 6, 177, "Input"]
}, Open  ]],
Cell[24017, 926, 67, 1, 62, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24109, 931, 171, 4, 97, "Text",
  Evaluatable->False],
Cell[24283, 937, 580, 13, 392, "Input"],
Cell[24866, 952, 86, 3, 74, "Input"],
Cell[24955, 957, 227, 5, 132, "Text",
  Evaluatable->False],
Cell[25185, 964, 293, 10, 277, "Input"],
Cell[25481, 976, 57, 1, 101, "Text",
  Evaluatable->False],
Cell[25541, 979, 205, 6, 161, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[25795, 991, 81, 1, 76, "Section",
  Evaluatable->False],
Cell[25879, 994, 285, 10, 300, "Input"],
Cell[26167, 1006, 49, 1, 62, "Text",
  Evaluatable->False],
Cell[26219, 1009, 101, 4, 116, "Input"],

Cell[CellGroupData[{
Cell[26345, 1017, 111, 3, 62, "Text",
  Evaluatable->False],
Cell[26459, 1022, 49, 1, 45, "Special1",
  Evaluatable->False],
Cell[26511, 1025, 566, 12, 288, "SmallText",
  Evaluatable->False]
}, Open  ]],
Cell[27092, 1040, 38, 1, 62, "Text",
  Evaluatable->False],
Cell[27133, 1043, 228, 5, 132, "Text",
  Evaluatable->False],
Cell[27364, 1050, 382, 17, 545, "Input"],
Cell[27749, 1069, 57, 1, 97, "Text",
  Evaluatable->False],
Cell[27809, 1072, 196, 8, 230, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28042, 1085, 71, 1, 76, "Section",
  Evaluatable->False],
Cell[28116, 1088, 285, 8, 238, "Input"],
Cell[28404, 1098, 101, 4, 116, "Input"],
Cell[28508, 1104, 165, 4, 97, "Text",
  Evaluatable->False],
Cell[28676, 1110, 178, 6, 177, "Input"],
Cell[28857, 1118, 171, 5, 146, "Text",
  Evaluatable->False],
Cell[29031, 1125, 356, 17, 506, "Input"],
Cell[29390, 1144, 36, 1, 48, "Input"],
Cell[29429, 1147, 273, 9, 146, "Text",
  Evaluatable->False],
Cell[29705, 1158, 172, 5, 146, "Text",
  Evaluatable->False],
Cell[29880, 1165, 76, 1, 97, "Text",
  Evaluatable->False],
Cell[29959, 1168, 361, 17, 545, "Input"],
Cell[30323, 1187, 39, 0, 54, "Input"],
Cell[30365, 1189, 164, 4, 97, "Text",
  Evaluatable->False],
Cell[30532, 1195, 45, 0, 54, "Input"],
Cell[30580, 1197, 57, 1, 62, "Text",
  Evaluatable->False],
Cell[30640, 1200, 204, 8, 238, "Input"],
Cell[30847, 1210, 56, 1, 62, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[30940, 1216, 253, 6, 188, "Section",
  Evaluatable->False],
Cell[31196, 1224, 748, 17, 416, "Special2",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31993, 1247, 118, 5, 132, "Section",
  Evaluatable->False],
Cell[32114, 1254, 125, 5, 154, "Text",
  Evaluatable->False],
Cell[32242, 1261, 90, 4, 74, "Input"],
Cell[32335, 1267, 188, 6, 207, "Text",
  Evaluatable->False],
Cell[32526, 1275, 99, 7, 161, "Input"],
Cell[32628, 1284, 121, 2, 101, "Text",
  Evaluatable->False],
Cell[32752, 1288, 78, 1, 47, "Input"],
Cell[32833, 1291, 200, 7, 260, "Text",
  Evaluatable->False],
Cell[33036, 1300, 71, 1, 47, "Input"],
Cell[33110, 1303, 61, 1, 47, "Input"],
Cell[33174, 1306, 150, 5, 154, "Text",
  Evaluatable->False],
Cell[33327, 1313, 82, 1, 47, "Input"],
Cell[33412, 1316, 175, 6, 207, "Text",
  Evaluatable->False],
Cell[33590, 1324, 89, 7, 161, "Input"],
Cell[33682, 1333, 256, 7, 260, "Text",
  Evaluatable->False],
Cell[33941, 1342, 72, 1, 47, "Input"],
Cell[34016, 1345, 64, 1, 47, "Input"],
Cell[34083, 1348, 64, 1, 47, "Input"],
Cell[34150, 1351, 151, 5, 154, "Text",
  Evaluatable->False],
Cell[34304, 1358, 112, 2, 78, "Input"],
Cell[34419, 1362, 223, 6, 207, "Text",
  Evaluatable->False],
Cell[34645, 1370, 166, 7, 161, "Input"],
Cell[34814, 1379, 92, 2, 101, "Text",
  Evaluatable->False],
Cell[34909, 1383, 44, 1, 47, "Input"],
Cell[34956, 1386, 207, 5, 154, "Text",
  Evaluatable->False],
Cell[35166, 1393, 480, 19, 509, "Input"],
Cell[35649, 1414, 355, 7, 207, "Text",
  Evaluatable->False],
Cell[36007, 1423, 820, 17, 709, "Input"],

Cell[CellGroupData[{
Cell[36852, 1444, 64, 1, 47, "Input"],
Cell[36919, 1447, 822, 17, 731, "Input"]
}, Open  ]],
Cell[37756, 1467, 132, 5, 154, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[37925, 1477, 86, 2, 76, "Section",
  Evaluatable->False],
Cell[38014, 1481, 227, 6, 207, "Text",
  Evaluatable->False],
Cell[38244, 1489, 310, 7, 207, "Text",
  Evaluatable->False],
Cell[38557, 1498, 148, 10, 248, "Input"],
Cell[38708, 1510, 210, 6, 154, "Text",
  Evaluatable->False],
Cell[38921, 1518, 90, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[39036, 1523, 463, 22, 596, "Input"],
Cell[39502, 1547, 37, 1, 47, "Input"]
}, Open  ]],
Cell[39554, 1551, 166, 5, 101, "Text",
  Evaluatable->False],
Cell[39723, 1558, 173, 6, 132, "Input"],
Cell[39899, 1566, 116, 2, 101, "Text",
  Evaluatable->False],
Cell[40018, 1570, 208, 5, 154, "Text",
  Evaluatable->False],
Cell[40229, 1577, 449, 21, 567, "Input"],
Cell[40681, 1600, 388, 12, 154, "Text",
  Evaluatable->False],
Cell[41072, 1614, 1170, 53, 1495, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42279, 1672, 99, 2, 73, "Subsection",
  Evaluatable->False],
Cell[42381, 1676, 214, 6, 132, "Input"],
Cell[42598, 1684, 215, 6, 122, "SmallText",
  Evaluatable->False],
Cell[42816, 1692, 64, 1, 45, "Input"],
Cell[42883, 1695, 252, 6, 122, "SmallText",
  Evaluatable->False],
Cell[43138, 1703, 84, 1, 45, "Input"],
Cell[43225, 1706, 365, 7, 122, "SmallText",
  Evaluatable->False],
Cell[43593, 1715, 180, 5, 154, "Text",
  Evaluatable->False],
Cell[43776, 1722, 234, 12, 306, "Input"],
Cell[44013, 1736, 84, 2, 101, "Text",
  Evaluatable->False],
Cell[44100, 1740, 368, 20, 538, "Input"],
Cell[44471, 1762, 86, 2, 101, "Text",
  Evaluatable->False],
Cell[44560, 1766, 498, 22, 596, "Input"],
Cell[45061, 1790, 176, 5, 101, "Text",
  Evaluatable->False],
Cell[45240, 1797, 377, 27, 741, "Input"],
Cell[45620, 1826, 164, 5, 101, "Text",
  Evaluatable->False],
Cell[45787, 1833, 377, 27, 741, "Input"],
Cell[46167, 1862, 119, 2, 101, "Text",
  Evaluatable->False],
Cell[46289, 1866, 378, 27, 741, "Input"],
Cell[46670, 1895, 139, 4, 101, "Text",
  Evaluatable->False],
Cell[46812, 1901, 62, 1, 45, "Input"],
Cell[46877, 1904, 118, 2, 101, "Text",
  Evaluatable->False],
Cell[46998, 1908, 78, 1, 45, "Input"],
Cell[47079, 1911, 249, 6, 207, "Text",
  Evaluatable->False],
Cell[47331, 1919, 930, 17, 1206, "Input"],
Cell[48264, 1938, 151, 5, 101, "Text",
  Evaluatable->False],
Cell[48418, 1945, 814, 44, 1205, "Input"],
Cell[49235, 1991, 105, 2, 101, "Text",
  Evaluatable->False],
Cell[49343, 1995, 817, 44, 1205, "Input"],
Cell[50163, 2041, 146, 4, 101, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[50346, 2050, 162, 5, 126, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50533, 2059, 49, 0, 93, "Subsubsection"],
Cell[50585, 2061, 156, 7, 190, "Input"],
Cell[50744, 2070, 80, 3, 154, "Text"],
Cell[50827, 2075, 56, 1, 47, "Input"],
Cell[50886, 2078, 30, 0, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50965, 2084, 119, 2, 73, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[51109, 2090, 50, 0, 85, "Subsubsection"],
Cell[51162, 2092, 36, 0, 101, "Text"],
Cell[51201, 2094, 166, 5, 132, "Input"],
Cell[51370, 2101, 52, 0, 101, "Text"],

Cell[CellGroupData[{
Cell[51447, 2105, 196, 9, 248, "Input"],
Cell[51646, 2116, 72, 0, 45, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51767, 2122, 50, 0, 85, "Subsubsection"],
Cell[51820, 2124, 36, 0, 101, "Text"],
Cell[51859, 2126, 166, 5, 132, "Input"],
Cell[52028, 2133, 108, 3, 101, "Text"],

Cell[CellGroupData[{
Cell[52161, 2140, 200, 9, 248, "Input"],
Cell[52364, 2151, 72, 0, 45, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52485, 2157, 54, 0, 85, "Subsubsection"],
Cell[52542, 2159, 36, 0, 101, "Text"],
Cell[52581, 2161, 172, 5, 132, "Input"],
Cell[52756, 2168, 76, 0, 101, "Text"],

Cell[CellGroupData[{
Cell[52857, 2172, 196, 9, 248, "Input"],
Cell[53056, 2183, 75, 0, 45, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53180, 2189, 63, 0, 85, "Subsubsection"],
Cell[53246, 2191, 36, 0, 101, "Text"],
Cell[53285, 2193, 172, 5, 132, "Input"],
Cell[53460, 2200, 118, 3, 101, "Text"],

Cell[CellGroupData[{
Cell[53603, 2207, 217, 9, 248, "Input"],
Cell[53823, 2218, 75, 0, 45, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

